# mmp-metadata
This is a API for MMP Metadata

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0-oas3
- Package version: 1.1.3
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import mmp_metadata_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import mmp_metadata_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import mmp_metadata_client
from mmp_metadata_client.rest import ApiException
from pprint import pprint


# Defining host is optional and default to https://localhost:8080/v1/metadata
configuration.host = "https://localhost:8080/v1/metadata"
# Create an instance of the API class
api_instance = mmp_metadata_client.ArtifactApi(mmp_metadata_client.ApiClient(configuration))
execution = 'execution_example' # str | The execution's id
artifact = mmp_metadata_client.Artifact() # Artifact | Artifact item to add (optional)

try:
    # adds an artifact
    api_response = api_instance.add_artifact(execution, artifact=artifact)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ArtifactApi->add_artifact: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost:8080/v1/metadata*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ArtifactApi* | [**add_artifact**](docs/ArtifactApi.md#add_artifact) | **POST** /experiments/runs/executions/{execution}/artifacts | adds an artifact
*ArtifactApi* | [**get_artifacts_by_execution**](docs/ArtifactApi.md#get_artifacts_by_execution) | **GET** /experiments/runs/executions/{execution}/artifacts | list of artifacts
*ArtifactApi* | [**get_artifacts_by_experiment**](docs/ArtifactApi.md#get_artifacts_by_experiment) | **GET** /experiments/{experiment}/artifacts | list of artifacts
*ArtifactApi* | [**get_artifacts_by_id**](docs/ArtifactApi.md#get_artifacts_by_id) | **GET** /experiments/runs/executions/artifacts/{artifact} | return artifact by id
*ArtifactApi* | [**get_artifacts_by_run**](docs/ArtifactApi.md#get_artifacts_by_run) | **GET** /experiments/runs/{run}/artifacts | list of artifacts
*ExecutionApi* | [**add_execution**](docs/ExecutionApi.md#add_execution) | **POST** /experiments/runs/{run}/executions | adds an execution
*ExecutionApi* | [**get_execution_by_id**](docs/ExecutionApi.md#get_execution_by_id) | **GET** /experiments/runs/executions/{execution} | run by id
*ExecutionApi* | [**get_executions_by_run**](docs/ExecutionApi.md#get_executions_by_run) | **GET** /experiments/runs/{run}/executions | list of executions
*ExecutionApi* | [**update_execution_by_id**](docs/ExecutionApi.md#update_execution_by_id) | **PUT** /experiments/runs/executions/{executionId} | update execution by id
*ExperimentApi* | [**add_experiment**](docs/ExperimentApi.md#add_experiment) | **POST** /experiments | adds an experiment
*ExperimentApi* | [**get_experiment_by_id**](docs/ExperimentApi.md#get_experiment_by_id) | **GET** /experiments/{experiment} | experiment by id
*ExperimentApi* | [**get_experiments**](docs/ExperimentApi.md#get_experiments) | **GET** /experiments | list of experiments
*ExperimentApi* | [**update_experiment_by_id**](docs/ExperimentApi.md#update_experiment_by_id) | **PUT** /experiments/{experimentId} | update experiment by id
*RunApi* | [**add_run**](docs/RunApi.md#add_run) | **POST** /experiments/{experiment}/runs | adds an run
*RunApi* | [**get_run_by_id**](docs/RunApi.md#get_run_by_id) | **GET** /experiments/runs/{run} | run by id
*RunApi* | [**get_runs_by_experiment**](docs/RunApi.md#get_runs_by_experiment) | **GET** /experiments/{experiment}/runs | list of runs
*RunApi* | [**update_run_by_id**](docs/RunApi.md#update_run_by_id) | **PUT** /experiments/runs/{runId} | update run by id
*TraceApi* | [**get_trace_by_experiment**](docs/TraceApi.md#get_trace_by_experiment) | **GET** /experiments/{experiment}/trace | one specific trace
*WorkflowApi* | [**get_workflow_by_run**](docs/WorkflowApi.md#get_workflow_by_run) | **GET** /experiments/run/{run}/workflow | one specific workflow


## Documentation For Models

 - [Artifact](docs/Artifact.md)
 - [Dataset](docs/Dataset.md)
 - [Event](docs/Event.md)
 - [Executable](docs/Executable.md)
 - [Execution](docs/Execution.md)
 - [Experiment](docs/Experiment.md)
 - [Metrics](docs/Metrics.md)
 - [Model](docs/Model.md)
 - [Pair](docs/Pair.md)
 - [Pipeline](docs/Pipeline.md)
 - [Run](docs/Run.md)
 - [Trace](docs/Trace.md)
 - [TraceArtifacts](docs/TraceArtifacts.md)
 - [TraceExecutionTypes](docs/TraceExecutionTypes.md)
 - [Workflow](docs/Workflow.md)
 - [WorkflowNode](docs/WorkflowNode.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

st116848@stud.uni-stuttgart.de.com


